==> tuia-advert-center-api-1.5.9-20180816.054112-61-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertApplyAppCouponInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

/**
 * Created by huangch on 2018/4/10 10:49
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertApplyAppCouponInfoDto {

    //申请id
    private Long applyId;

    //广告名称
    private String advertName;

    //默认素材图片
    private String bannerPng;

    //申请的状态
    private Integer applyStatus;

    //推广网址
    private String promoteURL;

    //按钮文案
    private String buttonText;

    //商品名称
    private String couponName;

    //商品说明
    private String couponRemark;

    //广告标签
    private String advertTag;

    //落地页标签
    private String landPageTag;

    public String getBannerPng() {
        return bannerPng;
    }

    public void setBannerPng(String bannerPng) {
        this.bannerPng = bannerPng;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getCouponRemark() {
        return couponRemark;
    }

    public void setCouponRemark(String couponRemark) {
        this.couponRemark = couponRemark;
    }

    public String getAdvertTag() {
        return advertTag;
    }

    public void setAdvertTag(String advertTag) {
        this.advertTag = advertTag;
    }

    public String getLandPageTag() {
        return landPageTag;
    }

    public void setLandPageTag(String landPageTag) {
        this.landPageTag = landPageTag;
    }
}

==> tuia-advert-center-api-2.2.73-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertApplyAppCouponInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;

/**
 * Created by huangch on 2018/4/10 10:49
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertApplyAppCouponInfoDto  implements Serializable {

    private static final long serialVersionUID = -86584279495396352L;
    //申请id
    private Long applyId;

    //广告名称
    private String advertName;

    //默认素材图片
    private String bannerPng;

    //创意素材默认大图文案
    private String defaultLargeImageDesc;

    //创意素材默认小图文案
    private String defaultSmallImageDesc;

    //创意素材默认大图
    private String defaultLargeImageUrl;

    //创意素材默认小图
    private String defaultSmallImageUrl;

    //申请的状态
    private Integer applyStatus;

    //推广网址
    private String promoteURL;

    //按钮文案
    private String buttonText;

    //商品名称
    private String couponName;

    //商品说明
    private String couponRemark;

    //广告标签
    private String advertTag;

    //落地页标签
    private String landPageTag;

    public String getDefaultLargeImageDesc() {
        return defaultLargeImageDesc;
    }

    public void setDefaultLargeImageDesc(String defaultLargeImageDesc) {
        this.defaultLargeImageDesc = defaultLargeImageDesc;
    }

    public String getDefaultSmallImageDesc() {
        return defaultSmallImageDesc;
    }

    public void setDefaultSmallImageDesc(String defaultSmallImageDesc) {
        this.defaultSmallImageDesc = defaultSmallImageDesc;
    }

    public String getDefaultLargeImageUrl() {
        return defaultLargeImageUrl;
    }

    public void setDefaultLargeImageUrl(String defaultLargeImageUrl) {
        this.defaultLargeImageUrl = defaultLargeImageUrl;
    }

    public String getDefaultSmallImageUrl() {
        return defaultSmallImageUrl;
    }

    public void setDefaultSmallImageUrl(String defaultSmallImageUrl) {
        this.defaultSmallImageUrl = defaultSmallImageUrl;
    }

    public String getBannerPng() {
        return bannerPng;
    }

    public void setBannerPng(String bannerPng) {
        this.bannerPng = bannerPng;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getCouponRemark() {
        return couponRemark;
    }

    public void setCouponRemark(String couponRemark) {
        this.couponRemark = couponRemark;
    }

    public String getAdvertTag() {
        return advertTag;
    }

    public void setAdvertTag(String advertTag) {
        this.advertTag = advertTag;
    }

    public String getLandPageTag() {
        return landPageTag;
    }

    public void setLandPageTag(String landPageTag) {
        this.landPageTag = landPageTag;
    }
}
